==> gradle-0.1.4-sources.jar: ai/nextbillion/nexbillionmaven/UploadInfo.java <==
package ai.nextbillion.nexbillionmaven;

public class UploadInfo {

    public String groupId;
    public String artifactId;
    public String version;
    public String codeReportUrl;
    public String sdkName;
    public String sdkDescription;
    public boolean release;
    // maven2 user name
    public String userName;
    // maven2 user password
    public String password;
    // maven2 user email
    public String email;

    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }

    public String getArtifactId() {
        return artifactId;
    }

    public void setArtifactId(String artifactId) {
        this.artifactId = artifactId;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getCodeReportUrl() {
        return codeReportUrl;
    }

    public void setCodeReportUrl(String codeReportUrl) {
        this.codeReportUrl = codeReportUrl;
    }

    public String getSdkName() {
        return sdkName;
    }

    public void setSdkName(String sdkName) {
        this.sdkName = sdkName;
    }

    public String getSdkDescription() {
        return sdkDescription;
    }

    public void setSdkDescription(String sdkDescription) {
        this.sdkDescription = sdkDescription;
    }

    public boolean isRelease() {
        return release;
    }

    public void setRelease(boolean release) {
        this.release = release;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    @Override
    public String toString() {
        return "UploadInfo{" +
                "groupId='" + groupId + '\'' +
                ", artifactId='" + artifactId + '\'' +
                ", version='" + version + '\'' +
                ", codeReportUrl='" + codeReportUrl + '\'' +
                ", sdkName='" + sdkName + '\'' +
                ", sdkDescription='" + sdkDescription + '\'' +
                ", release=" + release +
                '}';
    }

}

==> gradle-0.1.9-sources.jar: ai/nextbillion/nexbillionmaven/UploadInfo.java <==
package ai.nextbillion.nexbillionmaven;

public class UploadInfo {

    public String groupId;
    public String artifactId;
    public String version;
    public String codeReportUrl;
    public String sdkName;
    public String sdkDescription;
    public boolean release;
    // maven2 user name
    public String userName;
    // maven2 user password
    public String password;
    // maven2 user email
    public String email = "";

    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }

    public String getArtifactId() {
        return artifactId;
    }

    public void setArtifactId(String artifactId) {
        this.artifactId = artifactId;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getCodeReportUrl() {
        return codeReportUrl;
    }

    public void setCodeReportUrl(String codeReportUrl) {
        this.codeReportUrl = codeReportUrl;
    }

    public String getSdkName() {
        return sdkName;
    }

    public void setSdkName(String sdkName) {
        this.sdkName = sdkName;
    }

    public String getSdkDescription() {
        return sdkDescription;
    }

    public void setSdkDescription(String sdkDescription) {
        this.sdkDescription = sdkDescription;
    }

    public boolean isRelease() {
        return release;
    }

    public void setRelease(boolean release) {
        this.release = release;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    @Override
    public String toString() {
        return "UploadInfo{" +
                "groupId='" + groupId + '\'' +
                ", artifactId='" + artifactId + '\'' +
                ", version='" + version + '\'' +
                ", codeReportUrl='" + codeReportUrl + '\'' +
                ", sdkName='" + sdkName + '\'' +
                ", sdkDescription='" + sdkDescription + '\'' +
                ", release=" + release +
                '}';
    }

}
